{ pkgs, gui ? false, ... }:

{
  environment.systemPackages = with pkgs; [
    # Audio
    abcde # cd ripper
    flac # flac encoder
    shntool # split audio with cue
    sidplayfp # SID chiptune player
    sox # “Swiss Army knife of audio manipulation”

    # Audio + Video
    mediainfo # show information about media files
    youtube-dl # universal video downloader

    # Images
    exiftool # manipulate EXIF meta data
    jpegoptim # lossless jpeg optimiser
    libwebp # tools for webp image format
    optipng # lossless png optimiser
    pngcrush
    pngquant # lossy png optimisers

    # Literature
    mupdf # document (pdf) viewer and tools
  ] ++ (
    if gui then [
      # Audio
      picard # musicbrainz tagger

      # Audio + Video
      ffmpeg-full # A/V multitool
      mkvtoolnix # matroska (de-)muxing
      (mpv.override { archiveSupport = true; vapoursynthSupport = true; }) # media player

      # Literature
      calibre # ebook library
      zathura # plugin based document viewer
    ] else [
      # Packages only installed when gui is disabled
      mkvtoolnix-cli # matroska (de-)muxing
    ]
  );

  hardware.opengl.extraPackages = with pkgs; if gui then [
    pkgs.vaapiIntel
  ] else [];
}
